@@ -10,34 +10,6 @@
 #include <gnome-xml/tree.h>
 #include <gnome-xml/parser.h>
 
-int _gnome_print_debug = -1;
-
-#if 0
-#ifdef	__GNUC__
-#define debugmsg (format, args...) (_gnome_print_debug == -1 ? (getenv ("GNOME_PRINT_DEBUG") ? printf(format, ##args ), _gnome_print_debug = 1 : _gnome_print_debug = 0) : (_gnome_print_debug ? printf( format, ##args ) : 0))
-#else	/* !__GNUC__ */
-#endif
-#endif
-static void
-debugmsg (const gchar *format,
-	  ...)
-{
-  if ( _gnome_print_debug == -1 )
-    {
-      if ( getenv ("GNOME_PRINT_DEBUG") )
-	_gnome_print_debug = 1;
-      else
-	_gnome_print_debug = 0;
-    }
-  if ( _gnome_print_debug )
-    {
-      va_list args;
-      va_start (args, format);
-      vprintf (format, args);
-      va_end (args);
-    }
-}
-
 #define noVERBOSE
 
 typedef struct _GnomeFontType1EncTab GnomeFontType1EncTab;
@@ -333,13 +305,13 @@ gnome_font_add_mapping (GnomeFontClass *class, char *fontname,
 
 
 #ifdef VERBOSE
-  debugmsg ("Adding %s %s\n", fontname, afm_fn);
+  g_print ("Adding %s %s\n", fontname, afm_fn);
 #endif
   if (gnome_font_find (class, fontname) >= 0)
     {
       /* already present in fontmap */
 #ifdef VERBOSE
-      debugmsg ("Font %s already present\n", fontname);
+      g_print ("Font %s already present\n", fontname);
 #endif
       return;
     }
@@ -350,7 +322,7 @@ gnome_font_add_mapping (GnomeFontClass *class, char *fontname,
   else if ((n_fonts & (n_fonts - 1)) == 0)
     {
 #ifdef VERBOSE
-      debugmsg ("reallocating to %d\n", n_fonts * 2);
+      g_print ("reallocating to %d\n", n_fonts * 2);
 #endif
       class->fontmap = g_realloc (class->fontmap,
 				  sizeof(GnomeFontMap) * n_fonts * 2);
@@ -399,7 +371,7 @@ gnome_font_refresh_font_dir (GnomeFontClass *class, char *dirname)
   FontInfo *fi;
   int status;
 
-  debugmsg (_("scanning dir %s\n"), dirname);
+  g_print (_("scanning dir %s\n"), dirname);
   dir = opendir (dirname);
   if (dir != NULL)
     {
@@ -410,14 +382,14 @@ gnome_font_refresh_font_dir (GnomeFontClass *class, char *dirname)
 	    break;
 	  if (gnome_font_is_afm_file (dir_ent->d_name))
 	    {
-	      debugmsg (_("checking file %s\n"), dir_ent->d_name);
+	      g_print (_("checking file %s\n"), dir_ent->d_name);
 	      fn = g_malloc (strlen (dirname) + strlen (dir_ent->d_name) + 2);
 	      sprintf (fn, _("%s/%s"), dirname, dir_ent->d_name);
 	      afm_f = fopen (fn, "rb");
 	      if (afm_f != NULL)
 		{
 		  status = parseFile (afm_f, &fi, P_G);
-		  debugmsg ("status = %d\n", status);
+		  g_print ("status = %d\n", status);
 		  if (status == 0)
 		    {
 		      gnome_font_add_mapping (class, fi->gfi->fontName, fn);
@@ -505,7 +477,7 @@ gnome_font_load_fontmap (GnomeFontClass *class, const char *fn)
   xmlDoc *doc;
 
 #ifdef VERBOSE
-  debugmsg ("filename %s\n", fn);
+  g_print ("filename %s\n", fn);
 #endif
 
   doc = xmlParseFile( fn );
@@ -555,8 +527,8 @@ gnome_font_load_fontmap (GnomeFontClass *class, const char *fn)
                             weight ? weight : "**missing**");
                 }
 #ifdef VERBOSE
-	      debugmsg ("%s %s %s %s %s %s\n",
-			fontname, afmfile, pfbfile, fullname, familyname, weight);
+	      printf ("%s %s %s %s %s %s\n",
+		      fontname, afmfile, pfbfile, fullname, familyname, weight);
 #endif
 	      g_free (weight);
 	      g_free (familyname);
@@ -718,7 +690,7 @@ gnome_font_load_afm (GnomeFontMap *fontmap_entry)
     {
       status = parseFile (afm_f, &fi, P_M | P_P);
 #ifdef VERBOSE
-      debugmsg (_("status loading %s = %d\n"), fontmap_entry->afm_fn, status);
+      g_print (_("status loading %s = %d\n"), fontmap_entry->afm_fn, status);
 #endif
       if (status == 0)
 	{
@@ -813,7 +785,7 @@ gnome_font_load_afm (GnomeFontMap *fontmap_entry)
 	      ktab[j].glyph2 = glyph2;
 	      ktab[j].x_amt = fi->pkd[i].xamt;
 #ifdef VERBOSE
-	      debugmsg ("kern pair %s(%d) %s(%d) %d\n",
+	      g_print ("kern pair %s(%d) %s(%d) %d\n",
 		       fi->pkd[i].name1, glyph1,
 		       fi->pkd[i].name2, glyph2,
 		       fi->pkd[i].xamt);
@@ -822,7 +794,7 @@ gnome_font_load_afm (GnomeFontMap *fontmap_entry)
 
 #ifdef VERBOSE
 	  for (i = 0; i < ktabsize; i++)
-	    debugmsg ("%d %d %d\n",
+	    g_print ("%d %d %d\n",
 		     ktab[i].glyph1, ktab[i].glyph2, ktab[i].x_amt);
 #endif
 
@@ -1522,8 +1494,8 @@ static void initialize_hashes ()
   /* build 2 way hashes for x vs font family names */
   while (ftx->print_name)
     {
-      debugmsg ("inserting family-->x mapping: '%s' --> '%s'\n",
-		ftx->print_name, ftx->x_name);
+      printf ("inserting family-->x mapping: '%s' --> '%s'\n",
+	      ftx->print_name, ftx->x_name);
       g_hash_table_insert (gnome_font_family_to_x_hash,
 			   ftx->print_name, ftx->x_name);
       g_hash_table_insert (gnome_font_x_to_family_hash,
@@ -1535,7 +1507,7 @@ static void initialize_hashes ()
   /* build 2 way hashes for gnome font weight to x names */
   while (wtx->name)
     {
-      debugmsg ("inserting weight-->string mapping: '%d' --> '%s'\n",
+      printf ("inserting weight-->string mapping: '%d' --> '%s'\n",
 	      wtx->weight, wtx->name);
       g_hash_table_insert (gnome_font_weight_to_string_hash,
 			   & (wtx->weight), wtx->name);
@@ -1696,7 +1668,7 @@ static GdkFont *find_best_x_font (char *unsized_name,
   /*space_width = gnome_font_get_width_string (gnome_font, " ");*/
   /*max_width = perfect_width + space_width / 2;*/
   max_width = perfect_width /*- 1*/;
-  debugmsg( "perfect_width = %f\n", perfect_width );
+  g_print( "perfect_width = %f\n", perfect_width );
 #endif
   current_size = (int) (gnome_font->size);
   current_x_name = setFontPixelSize (unsized_name, current_size);
@@ -1705,19 +1677,19 @@ static GdkFont *find_best_x_font (char *unsized_name,
   /* start by getting some x font loaded */
   if (current_font == NULL)
     {
-      debugmsg ("couldn't load first font '%s'\n", current_x_name);
+      printf ("couldn't load first font '%s'\n", current_x_name);
       /* is it italic? */
       if (gnome_font->fontmap_entry->italic)
 	{
 	  /* try oblique */
-	  debugmsg ("trying oblique...\n");
+	  printf ("trying oblique...\n");
 	  setComponentReplace (&current_x_name, setFontSlant, "o");
 	  current_font = find_best_x_weight (current_x_name, gnome_font->fontmap_entry->weight_code);
 
 	  if (current_font == NULL)
 	    {
 	      /* failed.  put italic back */
-	      debugmsg ("oblique failed: '%s'\n", current_x_name);
+	      printf ("oblique failed: '%s'\n", current_x_name);
 	      setComponentReplace (&current_x_name, setFontSlant, "i");
 	    }
 	}
@@ -1725,25 +1697,25 @@ static GdkFont *find_best_x_font (char *unsized_name,
       if (current_font == NULL)
 	{
 	  /* try helvetica */
-	  debugmsg ("trying hevletica...\n");
+	  printf ("trying hevletica...\n");
 	  setComponentReplace (&current_x_name, setFontFamily, "helvetica");
 	  current_font = find_best_x_weight (current_x_name, gnome_font->fontmap_entry->weight_code);
 
 	  if (current_font == NULL)
 	    {
-	      debugmsg ("helvetica failed. giving up...\n");
+	      printf ("helvetica failed. giving up...\n");
 	      return NULL;
 	    }
 	}
     }
 
-  debugmsg ("initial name loaded: '%s'\n", current_x_name);
+  printf ("initial name loaded: '%s'\n", current_x_name);
 
 #if 0
   current_width = gdk_text_width (current_font, test_string, length);
   current_diff = (int) (perfect_width - current_width);
 
-  debugmsg ("size=%d, starting diff=%d\n", current_size, current_diff);
+  printf ("size=%d, starting diff=%d\n", current_size, current_diff);
 
   /* are we looking for a bigger x font or a smaller one? */
   /*
@@ -1755,14 +1727,14 @@ static GdkFont *find_best_x_font (char *unsized_name,
       /*direction = (int) gnome_font->size / 6.0;*/
       direction = 10;
       /*if (direction < 1) direction = 1;*/
-      debugmsg ("size=%f, direction=%d\n", gnome_font->size, direction);
+      printf ("size=%f, direction=%d\n", gnome_font->size, direction);
     }
   else
     {
       /*direction = (int) gnome_font->size / -6.0;*/
       direction = -10;
       /*if (direction > -1) direction = -1;*/
-      debugmsg ("size=%f, direction=%d\n", gnome_font->size, direction);
+      printf ("size=%f, direction=%d\n", gnome_font->size, direction);
     }
 
 
@@ -1776,7 +1748,7 @@ static GdkFont *find_best_x_font (char *unsized_name,
 
       if (next_font == NULL)
 	{
-	  debugmsg ("couldn't load '%s'\n", next_x_name);
+	  printf ("couldn't load '%s'\n", next_x_name);
 	  continue; /* ??? */
 	}
       next_width = gdk_text_width (next_font, test_string, length);
@@ -1785,7 +1757,7 @@ static GdkFont *find_best_x_font (char *unsized_name,
       /* if we've gotten bigger than max_width, stop */
       if (next_width >= max_width && direction > 0)
 	{
-	  debugmsg (" bailing because next_width[%d] >= max_width[%d]\n",
+	  printf (" bailing because next_width[%d] >= max_width[%d]\n",
 		  next_width, (int) max_width);
 	  break;
 	}
@@ -1793,7 +1765,7 @@ static GdkFont *find_best_x_font (char *unsized_name,
       /* if the previous font was closer than this one, stop */
       if (iabs (next_diff) > iabs (current_diff))
 	{
-	  debugmsg (" bailing because next_diff[%d] > current_diff[%d]\n",
+	  printf (" bailing because next_diff[%d] > current_diff[%d]\n",
 		  next_diff, current_diff);
 	  break;
 	}
@@ -1806,7 +1778,7 @@ static GdkFont *find_best_x_font (char *unsized_name,
       current_font = next_font;
       current_diff = next_diff;
 
-      debugmsg (" new size=%d, new diff=%d\n", current_size, current_diff);
+      printf (" new size=%d, new diff=%d\n", current_size, current_diff);
     }
 #endif
   (*x_font_name_ret) = current_x_name;
@@ -1881,7 +1853,7 @@ GnomeDisplayFont *gnome_get_display_font (char *family,
   if (! scaled_display_fonts) initialize_hashes ();
 
   /*
-  debugmsg ("lookup_display_font -- hash:%p key='%s'\n",
+  printf ("lookup_display_font -- hash:%p key='%s'\n",
 	  scaled_display_fonts,
 	  key);
   */
