@@ -95,18 +95,11 @@ gnome_print_ps_setrgbcolor (GnomePrintContext *pc,
 {
   GnomePrintPs *ps = GNOME_PRINT_PS (pc);
 
-  /* I think there's a problem:
-   * gsave, setcolor, grestore means a setrgbcolor is required;
-   * ps->r, etc. are the "last set" color, not the "current color"
-   * so you need a color stack to do this optimization.
-   */
-#if 0
   /* if the current color is the color the user wants to set, noop */
   if (ps->r == r &&
       ps->g == g &&
       ps->b == b)
     return 0;
-#endif
 
   ps->r = r; ps->g = g; ps->b = b;
 
@@ -288,12 +281,9 @@ gnome_print_ps_setfont (GnomePrintContext *pc, GnomeFont *font)
 	}
     }
 
-  /* This doesn't consider gsave/grestore... */
-#if 0
   if (ps->current_font && strcmp (ps->current_font, fontname) == 0 &&
       ps->current_font_size == font->size)
     return 0; /* this font is already set */
-#endif
 
   ps->current_font = fontname;
   ps->current_font_size = font->size;
