@@ -2,12 +2,12 @@
 #include <gnome.h>
 #include <sys/stat.h>
 
-#include "gnome-printer.h"
-#include "gnome-print.h"
-#include "gnome-print-meta.h"
-#include "gnome-font.h"
-#include "gnome-printer-profile.h"
-#include "gnome-printer-dialog.h"
+#include <libgnomeprint/gnome-printer.h>
+#include <libgnomeprint/gnome-print.h>
+#include <libgnomeprint/gnome-print-meta.h>
+#include <libgnomeprint/gnome-font.h>
+#include <libgnomeprint/gnome-printer-profile.h>
+#include <libgnomeprint/gnome-printer-dialog.h>
 
 static void
 print_test_page (GnomePrintContext *pc)
