@@ -2,12 +2,12 @@
 #include <gnome.h>
 #include <math.h>
 
-#include "gnome-printer.h"
-#include "gnome-print.h"
-#include "gnome-font.h"
-#include "gnome-printer-profile.h"
-#include "gnome-printer-dialog.h"
-#include "gnome-text.h"
+#include <libgnomeprint/gnome-printer.h>
+#include <libgnomeprint/gnome-print.h>
+#include <libgnomeprint/gnome-font.h>
+#include <libgnomeprint/gnome-printer-profile.h>
+#include <libgnomeprint/gnome-printer-dialog.h>
+#include <libgnomeprint/gnome-text.h>
 
 static GnomeTextLine *
 get_line (const char *fontlist, const char *string, double size)
